Method: Ridley::RoleObject#set_default_attribute
- Defined in:
- lib/ridley/chef_objects/role_object.rb
#set_default_attribute(key, value) ⇒ Hashie::Mash
Set a role level default attribute given the dotted path representation of the Chef attribute and value
56 57 58 59 |
# File 'lib/ridley/chef_objects/role_object.rb', line 56 def set_default_attribute(key, value) attr_hash = Hashie::Mash.from_dotted_path(key, value) self.default_attributes = self.default_attributes.deep_merge(attr_hash) end |